
#include <stdlib.h>
#include <math.h>
#include <GL/glut.h>
#include "glm.h"

GLMmodel* pmodel = NULL;
int viewportDistorted = 1;


void drawModel(void) {

  if (!pmodel) {
	pmodel = glmReadOBJ("bronco.obj");
	if(!pmodel)
	  exit(0);
	glmUnitize(pmodel);
	glmFacetNormals(pmodel);
	glmVertexNormals(pmodel, 90.0);
  }
  glmDraw(pmodel, GLM_SMOOTH | GLM_MATERIAL);
}

// a non-distored view by making the viewport smaller
void setAspect( int w, int h )
{ 
  if( viewportDistorted )
	  glViewport(0, 0, w, h);
  else 
  {
	  if( w > h )
		  glViewport(0, 0, h, h);
	  else
		  glViewport(0, 0, w, w);

	  /*
	  GLfloat aspect;
	  aspect = (GLfloat)w / (GLfloat)h;  
	  if( aspect > 1.0 )
		  glViewport(0, 0, w/aspect, h);
	  else
		  glViewport(0, 0, w, h*aspect);
	  */
  }
}
void Reshape(int w, int h) {

  setAspect( w, h ); // a non-distored view by making the viewport smaller

  glMatrixMode(GL_PROJECTION);
  glLoadIdentity();
  glOrtho(-1.15, 1.15, -1.15, 1.15, -10, 10);
  glMatrixMode(GL_MODELVIEW);
  glLoadIdentity();
  gluLookAt(0.0, 0.25, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);

  glEnable(GL_DEPTH_TEST);
  glShadeModel(GL_SMOOTH);

  glEnable(GL_LIGHTING);
  glEnable(GL_LIGHT0);
}


void Idle(void) {
 
  //glRotatef(0.2, 0, 1, 0);
  glutPostRedisplay();
}


void Display(void) {
 GLfloat pos[] = {0.0, 1.0, 1.0, 1.0};

  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

  glPushMatrix();
  glLoadIdentity();
  glLightfv(GL_LIGHT0, GL_POSITION, pos);
  glPopMatrix();


  glLoadIdentity();
  glRotatef(90, 0,1,0);
  drawModel();


  glutSwapBuffers();  
}


/* Esc causes the program to exit, SPACE changes the viewport aspect */
void Keyboard(unsigned char key, int x, int y) {
	if( key == ' ' )
	{
		viewportDistorted = !viewportDistorted;
		setAspect( glutGet( GLUT_WINDOW_WIDTH ), glutGet(  GLUT_WINDOW_HEIGHT ) );
		glutPostRedisplay();
	}
	else if( key == 27 )
        exit(0);
}


int main(int argc, char **argv) {

  glutInit(&argc, argv);
  glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGBA);

  glutCreateWindow("Viewport example - press SPACE for model aspect change, press Esc for exit");

  glutDisplayFunc(Display);

  glutReshapeFunc(Reshape);
  glutIdleFunc(Idle);
  glutKeyboardFunc(Keyboard);

  glutMainLoop();

  return 0;
}




